@@ -1,8 +1,5 @@
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE CPP #-}
-#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 702
-{-# LANGUAGE Trustworthy #-}
-#endif
 module Data.Key (
   -- * Keys
     Key
@@ -76,7 +73,7 @@ import Data.Functor.Identity
 import Data.Functor.Bind
 import Data.Functor.Compose
 import Data.Functor.Product
-import Data.Functor.Coproduct
+import qualified Data.Functor.Sum as Functor
 import Data.Foldable
 import Data.Hashable
 import Data.HashMap.Lazy (HashMap)
@@ -100,7 +97,7 @@ import Data.Traversable
 import qualified Data.List as List
 import Prelude hiding (lookup, zip, zipWith)
 
--- TODO: half of the functions manipulating Cofree and Free buil the keys in the wrong order
+-- TODO: half of the functions manipulating Cofree and Free build the keys in the wrong order
 
 type family Key (f :: * -> *)
 type instance Key (Cofree f) = Seq (Key f)
@@ -781,19 +778,19 @@ instance Ix i => Adjustable (Array i) where
   adjust f i arr  = arr Array.// [(i, f (arr Array.! i))]
   replace i b arr = arr Array.// [(i, b)]
 
-type instance Key (Coproduct f g) = (Key f, Key g)
+type instance Key (Functor.Sum f g) = (Key f, Key g)
 
-instance (Indexable f, Indexable g) => Indexable (Coproduct f g) where
-  index (Coproduct (Left a)) (x,_) = index a x
-  index (Coproduct (Right b)) (_,y) = index b y
+instance (Indexable f, Indexable g) => Indexable (Functor.Sum f g) where
+  index (Functor.InL a) (x,_) = index a x
+  index (Functor.InR b) (_,y) = index b y
 
-instance (Lookup f, Lookup g) => Lookup (Coproduct f g) where
-  lookup (x, _) (Coproduct (Left a)) = lookup x a
-  lookup (_, y) (Coproduct (Right b)) = lookup y b
+instance (Lookup f, Lookup g) => Lookup (Functor.Sum f g) where
+  lookup (x, _) (Functor.InL a) = lookup x a
+  lookup (_, y) (Functor.InR b) = lookup y b
 
-instance (Adjustable f, Adjustable g) => Adjustable (Coproduct f g) where
-  adjust f (x,_) (Coproduct (Left a)) = Coproduct (Left (adjust f x a))
-  adjust f (_,y) (Coproduct (Right b)) = Coproduct (Right (adjust f y b))
+instance (Adjustable f, Adjustable g) => Adjustable (Functor.Sum f g) where
+  adjust f (x,_) (Functor.InL a) = Functor.InL (adjust f x a)
+  adjust f (_,y) (Functor.InR b) = Functor.InR (adjust f y b)
 
 type instance Key (Product f g) = Either (Key f) (Key g)
 
